---
label: JRCLUST
dockerfile:
environment: MATLAB
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/jrclust/jrclust.py
notes: 
website: https://github.com/JaneliaSciComp/JRCLUST
source_code:
authors: James Jun and Alan Liddell
processor_name: JRClust
doi:
---

# JRCLUST

## Description

From the website: JRCLUST is a scalable and customizable package for spike sorting on high-density silicon probes. It is written in MATLAB and CUDA. JRCLUST was originally developed by James Jun and is currently maintained by Vidrio Technologies.

## References

